@@ -1,23 +1,26 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
 
 """
 Main file containing the mito widget.
 """
 import json
 import time
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
+from mitosheet.updates.replay_analysis import REPLAY_ANALYSIS_UPDATE
+from mitosheet.user.location import is_in_google_colab, is_in_vs_code
 import traitlets as t
 from ipywidgets import DOMWidget
 
 from mitosheet._frontend import module_name, module_version
 from mitosheet.api import API
 from mitosheet.data_in_mito import DataTypeInMito
-from mitosheet.errors import MitoError, get_recent_traceback
+from mitosheet.errors import MitoError, get_recent_traceback, make_execution_error
 from mitosheet.mito_analytics import (log, log_event_processed,
                                       log_recent_error, telemetry_turned_on)
 from mitosheet.saved_analyses import write_analysis
@@ -45,7 +48,7 @@ class MitoWidget(DOMWidget):
     analysis_data_json = t.Unicode('').tag(sync=True)
     user_profile_json = t.Unicode('').tag(sync=True)
     
-    def __init__(self, *args: List[Union[pd.DataFrame, str]]):
+    def __init__(self, *args: List[Union[pd.DataFrame, str]], analysis_to_replay: str=None):
         """
         Takes a list of dataframes and strings that are paths to CSV files
         passed through *args.
@@ -54,7 +57,7 @@ class MitoWidget(DOMWidget):
         super(MitoWidget, self).__init__()
             
         # Set up the state container to hold private widget state
-        self.steps_manager = StepsManager(args)
+        self.steps_manager = StepsManager(args, analysis_to_replay=analysis_to_replay)
 
         # Set up message handler
         self.on_msg(self.receive_message)
@@ -67,7 +70,6 @@ class MitoWidget(DOMWidget):
         # have to recompute them on each update
         last_50_usages = get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES)
         self.num_usages = len(last_50_usages if last_50_usages is not None else [])
-        self.usage_triggered_feedback_id = ''
         self.is_local_deployment = is_local_deployment()
         self.should_upgrade_mitosheet = should_upgrade_mitosheet()
         self.received_tours = get_user_field(UJ_RECEIVED_TOURS)
@@ -98,7 +100,6 @@ class MitoWidget(DOMWidget):
             'isLocalDeployment': self.is_local_deployment,
             'shouldUpgradeMitosheet': self.should_upgrade_mitosheet,
             'numUsages': self.num_usages,
-            'usageTriggeredFeedbackID': self.usage_triggered_feedback_id
         })
 
 
@@ -116,9 +117,6 @@ class MitoWidget(DOMWidget):
         # First, we send this new edit to the evaluator
         self.steps_manager.handle_edit_event(event)
 
-        # Update the usage_triggered_feedback_id variable
-        self.set_usage_triggered_feedback_id()
-
         # We update the state variables 
         self.update_shared_state_variables()
 
@@ -134,7 +132,6 @@ class MitoWidget(DOMWidget):
         })
 
 
-
     def handle_update_event(self, event: Dict[str, Any]) -> None:
         """
         This event is not the user editing the sheet, but rather information
@@ -146,11 +143,19 @@ class MitoWidget(DOMWidget):
         - Name of an existing analysis
         """
 
-        self.steps_manager.handle_update_event(event)
-
-        # Update all state variables
-        self.update_shared_state_variables()
+        try:
+            self.steps_manager.handle_update_event(event)
 
+            # Update all state variables
+            self.update_shared_state_variables()
+        except:
+            # We handle the case of replaying the analysis specially, because we don't
+            # want to display the error modal - we want to display something specific
+            # in this case. Note that we include the updating of shared state variables
+            # in the try catch, as this is sometimes where errors occur
+            if event["type"] == REPLAY_ANALYSIS_UPDATE['event_type']:
+                raise make_execution_error(error_modal=False)
+            raise
         # Also, write the analysis to a file!
         write_analysis(self.steps_manager)
 
@@ -180,7 +185,7 @@ class MitoWidget(DOMWidget):
         4. A log_event is just an event that should get logged on the backend.
         """
 
-        start_time = time.perf_counter()
+        start_time: Optional[float] = time.perf_counter()
         event = content
 
         try:
@@ -190,11 +195,12 @@ class MitoWidget(DOMWidget):
                 self.handle_update_event(event)
             elif event['event'] == 'api_call':
                 self.api.process_new_api_call(event)
-                return True
+                # NOTE: since API calls are in a seperate thread, their start time and end
+                # time are not valid, and so we don't even log the start time to not be confusing
+                start_time = None
             
             # NOTE: we don't need to case on log_event above because it always gets
-            # passed to this function, and thus is logged. However, we do not log
-            # api calls, as they are just noise.
+            # passed to this function, and thus is logged.
             log_event_processed(event, self.steps_manager, start_time=start_time)
 
             return True
@@ -243,19 +249,10 @@ class MitoWidget(DOMWidget):
 
         return False
 
-    def set_usage_triggered_feedback_id(self) -> None:
-        """
-        Determines if the user should be prompted for feedback. If it determines that we should ask the user for feedback, 
-        then it sets the feedback_id shared variable.
-
-        Current Feedback Strategy:
-        - Never ask for feedback
-        """
-        self.usage_triggered_feedback_id = ''
-
 def sheet(
         *args: Any,
-        view_df: bool=False # We use this param to log if the mitosheet.sheet call is created from the df output button
+        analysis_to_replay: str=None, # This is the parameter that tracks the analysis that you want to replay (NOTE: requires a frontend to be replayed!)
+        view_df: bool=False, # We use this param to log if the mitosheet.sheet call is created from the df output button,
         # NOTE: if you add named variables to this function, make sure argument parsing on the front-end still
         # works by updating the getArgsFromCellContent function.
     ) -> MitoWidget:
@@ -270,15 +267,22 @@ def sheet(
     python -m pip install mitoinstaller
     python -m mitoinstaller install
 
-    Run this command in the terminal where you installed Mito. It should take 5-10 minutes to complete.
+    Run this command in the terminal where you installed Mito. It should take 1-2 minutes to complete.
 
     Then, restart your JupyterLab instance, and refresh your browser. Mito should now render.
 
     NOTE: if you have any issues with installation, please email jake@sagacollab.com
     """
+    # We throw a custom error message if we're sure the user is in
+    # vs code or google collab (these conditions are more secure than
+    # the conditons for checking if we're in JLab or JNotebook).
+    if is_in_vs_code() or is_in_google_colab():
+        log_recent_error('mitosheet_sheet_call_location_failed')
+        raise Exception("The mitosheet currently only works in JupyterLab.\n\nTo see instructions on getting Mitosheet running in JupyterLab, find install instructions here: https://docs.trymito.io/getting-started/installing-mito")
+
     try:
         # We pass in the dataframes directly to the widget
-        widget = MitoWidget(*args) 
+        widget = MitoWidget(*args, analysis_to_replay=analysis_to_replay) 
 
         # Log they have personal data in the tool if they passed a dataframe
         # that is not tutorial data or sample data from import docs
