@@ -28,10 +28,6 @@ class GraphRenameStepPerformer(StepPerformer):
     @classmethod
     def step_display_name(cls) -> str:
         return 'Renamed a Graph'
-    
-    @classmethod
-    def step_event_type(cls) -> str:
-        return 'graph_rename_edit'
 
     @classmethod
     def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
@@ -54,7 +50,7 @@ class GraphRenameStepPerformer(StepPerformer):
             return prev_state, None
 
         # Create a new step and save the parameters
-        post_state = copy(prev_state)
+        post_state = prev_state.copy()
 
         post_state.graph_data_dict[graph_id]["graphTabName"] = new_graph_tab_name
         
