@@ -5,24 +5,29 @@
 # Distributed under the terms of the GPL License.
 
 import json
+import random
+import string
 import uuid
 from copy import copy, deepcopy
-import pandas as pd
-from typing import Any, Callable, Dict, Collection, List, Set, Tuple, Union
-from mitosheet.mito_analytics import log
+from typing import Any, Collection, Dict, List, Set, Tuple, Union
 
-from mitosheet.step_performers.import_steps.simple_import import (
-    SimpleImportStepPerformer,
-)
-from mitosheet.step_performers.import_steps.excel_import import ExcelImportStepPerformer
+import pandas as pd
+
+from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
+from mitosheet.mito_analytics import log
+from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
+from mitosheet.saved_analyses.save_utils import get_analysis_exists
 from mitosheet.state import State
 from mitosheet.step import Step
 from mitosheet.step_performers import EVENT_TYPE_TO_STEP_PERFORMER
-from mitosheet.updates import UPDATES
-from mitosheet.preprocessing import PREPROCESS_STEP_PERFORMERS
-from mitosheet.utils import dfs_to_array_for_json, get_new_id, is_default_df_names
+from mitosheet.step_performers.import_steps.excel_import import \
+    ExcelImportStepPerformer
+from mitosheet.step_performers.import_steps.simple_import import \
+    SimpleImportStepPerformer
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
+from mitosheet.updates import UPDATES
+from mitosheet.utils import (dfs_to_array_for_json, get_new_id,
+                             is_default_df_names)
 
 
 def get_step_indexes_to_skip(step_list: List[Step]) -> Set[int]:
@@ -157,7 +162,7 @@ class StepsManager:
     and parameters stay the same and are append-only.
     """
 
-    def __init__(self, args: Collection[Union[pd.DataFrame, str]]):
+    def __init__(self, args: Collection[Union[pd.DataFrame, str]], analysis_to_replay: str=None):
         """
         When initalizing the StepsManager, we also do preprocessing
         of the arguments that were passed to the mitosheet.
@@ -165,9 +170,13 @@ class StepsManager:
         All preprocessing can be found in mitosheet/preprocessing, and each of
         the transformations are applied before the data is considered imported.
         """
-        # We just randomly generate analysis names.
-        # We append a UUID to note that this is not an analysis the user has saved.
-        self.analysis_name = "UUID-" + str(uuid.uuid4())
+        # We just randomly generate analysis names as a string of 10 letters
+        self.analysis_name = 'id-' + ''.join(random.choice(string.ascii_lowercase) for _ in range(10))
+
+        # We also save some data about the analysis the user wants to replay, if there
+        # is such an analysis
+        self.analysis_to_replay = analysis_to_replay
+        self.analysis_to_replay_exists = get_analysis_exists(analysis_to_replay)
 
         # The args are a tuple of dataframes or strings, and we start by making them
         # into a list, and making copies of them for safe keeping
@@ -220,6 +229,16 @@ class StepsManager:
         self.saved_sheet_data: List[Dict] = []
         self.last_step_index_we_wrote_sheet_json_on = 0
 
+        # We store the number of update events that have been processed successfully,
+        # which allows us to have some awareness about undos and redos in the front-end
+        self.update_event_count = 0
+
+        # This stores the number of times that the sheet renders, and we use it to detect
+        # when we are on the first render of a sheet. This is very useful for making
+        # sure we only update the state of the backend on the first render of a sheet
+        # that corresponds to that backend
+        self.render_count = 0
+
     @property
     def curr_step(self) -> Step:
         """
@@ -272,11 +291,17 @@ class StepsManager:
         return json.dumps(
             {
                 "analysisName": self.analysis_name,
+                "analysisToReplay": {
+                    'analysisName': self.analysis_to_replay,
+                    'existsOnDisk': self.analysis_to_replay_exists,
+                } if self.analysis_to_replay is not None else None,
                 "code": transpile(self),
                 "stepSummaryList": self.step_summary_list,
                 "currStepIdx": self.curr_step_idx,
                 "dataTypeInTool": self.data_type_in_mito.value,
-                "graphDataJSON": self.curr_step.graph_data
+                "graphDataDict": self.curr_step.graph_data_dict,
+                'updateEventCount': self.update_event_count,
+                'renderCount': self.render_count
             }
         )
 
@@ -369,9 +394,12 @@ class StepsManager:
                 params = {key: value for key, value in update_event.items() if key in update["params"]}  # type: ignore
                 # Actually execute this event
                 update["execute"](self, **params)  # type: ignore
+                # Update the number of update events we record occuring
+                self.update_event_count += 1
                 # And then return
                 return
 
+
         raise Exception(f"{update_event} is not an update event!")
 
     def find_last_valid_index(self, new_steps: List[Step]) -> int:
@@ -446,7 +474,7 @@ class StepsManager:
         # If this works, then let's add this step to the undo list!
         self.undone_step_list_store.append(("undo", [undone_step]))
 
-    def execute_redo(self):
+    def execute_redo(self) -> None:
         """
         Executes a redo, which reapplies the most recently undone
         steps if they exist.
