@@ -136,7 +136,7 @@ def test_filter_conditions_match():
 
 def test_pivot_aggregation_functions_match():
     aggregation_types = get_enum_from_ts_file(
-        "./src/components/taskpanes/PivotTable/PivotTaskpane.tsx", "AggregationType"
+        "./src/types.tsx", "AggregationType"
     )
     assert set(aggregation_types.values()) == set(PIVOT_AGGREGATION_TYPES)
 
@@ -187,7 +187,7 @@ def test_format_types_fields_match():
 
 def test_graph_safety_filter_cutoff_matches():
     graph_safety_filter_cutoff = get_constant_from_ts_file(
-        "./src/components/taskpanes/Graph/GraphSidebar.tsx",
+        "./src/components/taskpanes/Graph/GraphSetupTab.tsx",
         "GRAPH_SAFETY_FILTER_CUTOFF",
     )
 
